==> jc-1.4.0.tar.gz: soot/jimple/parser/node/ASingleNameList.h <==
// public final class soot.jimple.parser.node.ASingleNameList

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class c0b431d078dbaad1 soot_jimple_parser_node_ASingleNameList
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class 8518a2eca4336d5f soot_jimple_parser_node_PNameList

// header file dependencies
// @dep_header soot_jimple_parser_node_PNameList

#include "soot/jimple/parser/node/PNameList.h"

#ifndef _JC_soot_jimple_parser_node_ASingleNameList_H_
#define _JC_soot_jimple_parser_node_ASingleNameList_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_PName$object;
struct _jc_soot_jimple_parser_node_Switch$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_ASingleNameList$sub_refs	_jc_soot_jimple_parser_node_ASingleNameList$sub_refs;
typedef struct _jc_soot_jimple_parser_node_ASingleNameList$sub_nonrefs	_jc_soot_jimple_parser_node_ASingleNameList$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_ASingleNameList$refs	_jc_soot_jimple_parser_node_ASingleNameList$refs;
typedef struct _jc_soot_jimple_parser_node_ASingleNameList$nonrefs	_jc_soot_jimple_parser_node_ASingleNameList$nonrefs;
typedef struct _jc_soot_jimple_parser_node_ASingleNameList$object	_jc_soot_jimple_parser_node_ASingleNameList$object;

typedef const struct _jc_soot_jimple_parser_node_ASingleNameList$vmethods	_jc_soot_jimple_parser_node_ASingleNameList$vmethods;
typedef const struct _jc_soot_jimple_parser_node_ASingleNameList$vtable	_jc_soot_jimple_parser_node_ASingleNameList$vtable;
typedef const struct _jc_soot_jimple_parser_node_ASingleNameList$vtype	_jc_soot_jimple_parser_node_ASingleNameList$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_ASingleNameList$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_ASingleNameList$object *);
extern void _jc_soot_jimple_parser_node_ASingleNameList$method$_init$dadd6f33d6c98eed(_jc_env *, struct _jc_soot_jimple_parser_node_ASingleNameList$object *, struct _jc_soot_jimple_parser_node_PName$object *);

// Virtual methods
extern void _jc_soot_jimple_parser_node_ASingleNameList$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_ASingleNameList$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_ASingleNameList$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_ASingleNameList$object *);
extern struct _jc_soot_jimple_parser_node_PName$object *_jc_soot_jimple_parser_node_ASingleNameList$method$getName$30a0ee8779f774c9(_jc_env *, struct _jc_soot_jimple_parser_node_ASingleNameList$object *);
extern void _jc_soot_jimple_parser_node_ASingleNameList$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_ASingleNameList$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_ASingleNameList$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_ASingleNameList$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_ASingleNameList$method$setName$34bb5e147ac8a9fb(_jc_env *, struct _jc_soot_jimple_parser_node_ASingleNameList$object *, struct _jc_soot_jimple_parser_node_PName$object *);
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_ASingleNameList$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_ASingleNameList$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_ASingleNameList$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_ASingleNameList$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_ASingleNameList$method_info$getName$30a0ee8779f774c9;
extern _jc_method _jc_soot_jimple_parser_node_ASingleNameList$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_ASingleNameList$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_ASingleNameList$method_info$setName$34bb5e147ac8a9fb;
extern _jc_method _jc_soot_jimple_parser_node_ASingleNameList$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_ASingleNameList$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_ASingleNameList$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_ASingleNameList$object *);
	struct _jc_soot_jimple_parser_node_PName$object	*(*getName$30a0ee8779f774c9)(_jc_env *, struct _jc_soot_jimple_parser_node_ASingleNameList$object *);
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_ASingleNameList$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_ASingleNameList$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*setName$34bb5e147ac8a9fb)(_jc_env *, struct _jc_soot_jimple_parser_node_ASingleNameList$object *, struct _jc_soot_jimple_parser_node_PName$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_ASingleNameList$object *);
};

// Vtable
struct _jc_soot_jimple_parser_node_ASingleNameList$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PNameList$vmethods	soot_jimple_parser_node_PNameList;
	_jc_soot_jimple_parser_node_ASingleNameList$vmethods	soot_jimple_parser_node_ASingleNameList;
};

// Vtype
struct _jc_soot_jimple_parser_node_ASingleNameList$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_ASingleNameList$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ASingleNameList$sub_refs {
	struct _jc_soot_jimple_parser_node_PName$object	*__5fname__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_ASingleNameList$refs {
    _jc_soot_jimple_parser_node_ASingleNameList$sub_refs	soot_jimple_parser_node_ASingleNameList;
    _jc_soot_jimple_parser_node_PNameList$sub_refs	soot_jimple_parser_node_PNameList;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ASingleNameList$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_ASingleNameList$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PNameList$sub_nonrefs	soot_jimple_parser_node_PNameList;
    _jc_soot_jimple_parser_node_ASingleNameList$sub_nonrefs	soot_jimple_parser_node_ASingleNameList;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_ASingleNameList$object {
	_jc_soot_jimple_parser_node_ASingleNameList$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_ASingleNameList$vtype	*vtype;
	_jc_soot_jimple_parser_node_ASingleNameList$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_ASingleNameList$vtype _jc_soot_jimple_parser_node_ASingleNameList$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_ASingleNameList, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_ASingleNameList$class_object;

#endif	/* _JC_soot_jimple_parser_node_ASingleNameList_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/parser/node/ASingleNameList.h <==
// public final class soot.jimple.parser.node.ASingleNameList

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class c0b431d078dbaad1 soot_jimple_parser_node_ASingleNameList
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class 8518a2eca4336d5f soot_jimple_parser_node_PNameList

// header file dependencies
// @dep_header soot_jimple_parser_node_PNameList

#include "soot/jimple/parser/node/PNameList.h"

#ifndef _JC_soot_jimple_parser_node_ASingleNameList_H_
#define _JC_soot_jimple_parser_node_ASingleNameList_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_PName$object;
struct _jc_soot_jimple_parser_node_Switch$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_ASingleNameList$sub_refs	_jc_soot_jimple_parser_node_ASingleNameList$sub_refs;
typedef struct _jc_soot_jimple_parser_node_ASingleNameList$sub_nonrefs	_jc_soot_jimple_parser_node_ASingleNameList$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_ASingleNameList$refs	_jc_soot_jimple_parser_node_ASingleNameList$refs;
typedef struct _jc_soot_jimple_parser_node_ASingleNameList$nonrefs	_jc_soot_jimple_parser_node_ASingleNameList$nonrefs;
typedef struct _jc_soot_jimple_parser_node_ASingleNameList$object	_jc_soot_jimple_parser_node_ASingleNameList$object;

typedef const struct _jc_soot_jimple_parser_node_ASingleNameList$vmethods	_jc_soot_jimple_parser_node_ASingleNameList$vmethods;
typedef const struct _jc_soot_jimple_parser_node_ASingleNameList$vtable	_jc_soot_jimple_parser_node_ASingleNameList$vtable;
typedef const struct _jc_soot_jimple_parser_node_ASingleNameList$vtype	_jc_soot_jimple_parser_node_ASingleNameList$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_ASingleNameList$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_ASingleNameList$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ASingleNameList$method$_init$dadd6f33d6c98eed(_jc_env *, struct _jc_soot_jimple_parser_node_ASingleNameList$object *, struct _jc_soot_jimple_parser_node_PName$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_parser_node_ASingleNameList$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_ASingleNameList$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_ASingleNameList$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_ASingleNameList$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_jimple_parser_node_PName$object *_jc_soot_jimple_parser_node_ASingleNameList$method$getName$30a0ee8779f774c9(_jc_env *, struct _jc_soot_jimple_parser_node_ASingleNameList$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ASingleNameList$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_ASingleNameList$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ASingleNameList$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_ASingleNameList$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ASingleNameList$method$setName$34bb5e147ac8a9fb(_jc_env *, struct _jc_soot_jimple_parser_node_ASingleNameList$object *, struct _jc_soot_jimple_parser_node_PName$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_ASingleNameList$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_ASingleNameList$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_ASingleNameList$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_ASingleNameList$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_ASingleNameList$method_info$getName$30a0ee8779f774c9;
extern _jc_method _jc_soot_jimple_parser_node_ASingleNameList$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_ASingleNameList$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_ASingleNameList$method_info$setName$34bb5e147ac8a9fb;
extern _jc_method _jc_soot_jimple_parser_node_ASingleNameList$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_ASingleNameList$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_ASingleNameList$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_ASingleNameList$object *) _JC_JCNI_ATTR;
	struct _jc_soot_jimple_parser_node_PName$object	*(*getName$30a0ee8779f774c9)(_jc_env *, struct _jc_soot_jimple_parser_node_ASingleNameList$object *) _JC_JCNI_ATTR;
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_ASingleNameList$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_ASingleNameList$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*setName$34bb5e147ac8a9fb)(_jc_env *, struct _jc_soot_jimple_parser_node_ASingleNameList$object *, struct _jc_soot_jimple_parser_node_PName$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_ASingleNameList$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_parser_node_ASingleNameList$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PNameList$vmethods	soot_jimple_parser_node_PNameList;
	_jc_soot_jimple_parser_node_ASingleNameList$vmethods	soot_jimple_parser_node_ASingleNameList;
};

// Vtype
struct _jc_soot_jimple_parser_node_ASingleNameList$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_ASingleNameList$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ASingleNameList$sub_refs {
	struct _jc_soot_jimple_parser_node_PName$object	*__5fname__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_ASingleNameList$refs {
    _jc_soot_jimple_parser_node_ASingleNameList$sub_refs	soot_jimple_parser_node_ASingleNameList;
    _jc_soot_jimple_parser_node_PNameList$sub_refs	soot_jimple_parser_node_PNameList;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ASingleNameList$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_ASingleNameList$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PNameList$sub_nonrefs	soot_jimple_parser_node_PNameList;
    _jc_soot_jimple_parser_node_ASingleNameList$sub_nonrefs	soot_jimple_parser_node_ASingleNameList;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_ASingleNameList$object {
	_jc_soot_jimple_parser_node_ASingleNameList$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_ASingleNameList$vtype	*vtype;
	_jc_soot_jimple_parser_node_ASingleNameList$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_ASingleNameList$vtype _jc_soot_jimple_parser_node_ASingleNameList$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_ASingleNameList, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_ASingleNameList$class_object;

#endif	/* _JC_soot_jimple_parser_node_ASingleNameList_H_ */
